@@ -119,9 +119,9 @@ relay_add_pull_to_list (char *arg)
 	generate_http_request (arg, &(new->req));
 
 	if (localmount[0])
-		strcpy (new->localmount, localmount);
+		strncpy(new->localmount, localmount, BUFSIZE);
 	else
-		sprintf (new->localmount, "%s:%d%s", new->req.host, new->req.port, new->req.path);
+		snprintf(new->localmount, BUFSIZE, "%s:%d%s", new->req.host, new->req.port, new->req.path);
 
 	relay_insert (new);
 
@@ -174,7 +174,7 @@ relay_add_push_to_list (char *arg)
 
 	relay = relay_create ();
 
-	strcpy (relay->localmount, con->food.source->audiocast.mount);
+	strncpy(relay->localmount, con->food.source->audiocast.mount, BUFSIZE);
 	generate_http_request (arg, &relay->req);
 	
 	strncpy (password, info.encoder_pass, BUFSIZE);
@@ -192,14 +192,14 @@ relay_add_push_to_list (char *arg)
 		if (splitc (buf, arg, ' ') == NULL)
 		{
 			go_on = 0;
-			strcpy (buf, arg);
+			strncpy(buf, arg, BUFSIZE);
 		} else {
 			if (buf[0] == '-' && buf[1] != 'i' && splitc (carg, arg, ' ') != NULL)
 			{
 				if (carg[0] == '-' || (ice_strcmp (carg, buf) == 0))
 					return ICE_ERROR_ARGUMENT_REQUIRED;
 			} else {
-				strcpy (carg, arg);
+				strncpy(carg, arg, BUFSIZE);
 			}
 		}
 		
@@ -318,9 +318,9 @@ relay_find_with_req (request_t *req)
 {
 	relay_t rel, *out = NULL;
 
-	strcpy (rel.req.host, req->host);
+	strncpy(rel.req.host, req->host, BUFSIZE);
 	rel.req.port = req->port;
-	strcpy (rel.req.path, req->path);
+	strncpy(rel.req.path, req->path, BUFSIZE);
 	
 	thread_mutex_lock (&info.relay_mutex);
 	out = avl_find (info.relays, &rel);
@@ -706,7 +706,7 @@ login_as_client_on_server (connection_t *con, request_t *req, char *buf)
 	con->sock = sockfd;
 	con->connect_time = get_time ();
 
-	sprintf (buf, "%s:%d%s", req->host, req->port, req->path);
+	snprintf(buf, BUFSIZE, "%s:%d%s", req->host, req->port, req->path);
 
 	con->food.source->audiocast.mount = nstrdup (buf);
 	
