@@ -529,8 +529,8 @@ int sock_write_bytes(SOCKET sockfd, const char *buff, int len)
 	for(t=0 ; len > 0 ; ) {
 		int n=send(sockfd, buff+t, len, 0);
 
-		if(n < 0)
-		    return n;
+		if (n < 0)
+		    return (t == 0) ? n : t;
 		t+=n;
 		len-=n;
 	}
