@@ -178,6 +178,7 @@ timer_handle_directory_servers (time_t stime)
 {
 	avl_traverser trav = {0};
 	directory_server_t *ds;
+	connection_t *defcon = get_default_mount();
 	
 	if ((stime - info.directorylasttime) >= info.touch_freq * 60) {
 		/* First xa servers, then icy servers.
@@ -185,7 +186,6 @@ timer_handle_directory_servers (time_t stime)
 		   the xa stuff, because we're traversing multiple
 		   sources and stuff. And with icy, we can't double lock
 		   at all, because friggin yp.shoutcast.com sux ass */
-	        connection_t *defcon = get_default_mount();
 		zero_trav(&trav);
 		
 		thread_mutex_lock(&info.double_mutex);
@@ -212,8 +212,7 @@ timer_handle_directory_servers (time_t stime)
 		thread_mutex_lock (&info.directory_mutex);
 
 		while ((ds = avl_traverse(info.d_servers, &trav))) {
-			if (ds->type != icy_e)
-				continue;
+			if (ds->type != icy_e) continue;
 	
 			if ((ds->id < 0) && (ds->counter > 0) 
 			    && ((stime - ds->touchtime) < (info.touch_freq * ds->counter * 60))) {
@@ -222,16 +221,27 @@ timer_handle_directory_servers (time_t stime)
 				continue;
 			}
 			
-			if (ds->id == -1)
-				directory_add(ds, defcon);
-			else
+			if (ds->id == -1) {
+				if (defcon != NULL) {
+					directory_add(ds, defcon);
+					directory_touch(ds, defcon);
+				}
+			} else {
 				directory_touch(ds, defcon);
+			}
 			ds->touchtime = stime;
 		}
 
 		thread_mutex_unlock (&info.directory_mutex);
 
 		info.directorylasttime = stime;
+	} else if (defcon == NULL) {
+		thread_mutex_lock(&info.directory_mutex);
+		while ((ds = avl_traverse(info.d_servers, &trav))) {
+			if (ds->type != icy_e) continue;
+			if (ds->id != -1) directory_remove(ds);
+		}
+		thread_mutex_unlock(&info.directory_mutex);
 	}
 }
 
@@ -708,7 +718,7 @@ void add_fmt_string(char *buf, const char *fmt, char *val)
 	if (ice_strlen (val) > 230)
 		val[230] = '\0';
 
-	sprintf(buf2, fmt, val);
+	snprintf(buf2, 256, fmt, val);
 	strncat(buf, buf2, 1023 - ice_strlen (buf));
 }
 
@@ -717,7 +727,7 @@ void add_fmt_int(char *buf, const char *fmt, long int val)
 	char buf2[256];
 	if (!buf || !fmt)
 		return;
-	sprintf(buf2, fmt, val);
+	snprintf(buf2, 256, fmt, val);
 	strncat(buf, buf2, 1023 - ice_strlen (buf));
 }
 
